@@ -1,8 +1,8 @@
 /**************************************
-           VERSIONED VIEWS (4.1)
+           VERSIONED VIEWS (4.4)
 **************************************/
 
-CREATE OR REPLACE VIEW v4_1_enum_translator
+CREATE OR REPLACE VIEW v4_4_enum_translator
  AS
 SELECT
     enum_translator.enum_type as enum_type,
@@ -13,7 +13,7 @@ FROM enum_translator INNER JOIN
                 (enum_translator.language_code = history_configuration.var_value
                 and history_configuration.var_name = 'default_language');
 
-CREATE OR REPLACE VIEW v4_1_configuration_history_datacenters
+CREATE OR REPLACE VIEW v4_4_configuration_history_datacenters
  AS
 SELECT
       history_id as history_id,
@@ -26,7 +26,7 @@ SELECT
       delete_date as delete_date
 FROM datacenter_configuration;
 
-CREATE OR REPLACE VIEW v4_1_latest_configuration_datacenters
+CREATE OR REPLACE VIEW v4_4_latest_configuration_datacenters
  AS
 SELECT
       history_id as history_id,
@@ -40,7 +40,7 @@ FROM datacenter_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM datacenter_configuration as a GROUP BY a.datacenter_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_map_history_datacenters_storage_domains
+CREATE OR REPLACE VIEW v4_4_map_history_datacenters_storage_domains
  AS
 SELECT
     history_id as history_id,
@@ -50,7 +50,7 @@ SELECT
     detach_date as detach_date
 FROM         datacenter_storage_domain_map;
 
-CREATE OR REPLACE VIEW v4_1_latest_map_datacenters_storage_domains
+CREATE OR REPLACE VIEW v4_4_latest_map_datacenters_storage_domains
  AS
 SELECT
     history_id as history_id,
@@ -61,7 +61,7 @@ FROM         datacenter_storage_domain_map
 WHERE history_id in (SELECT max(a.history_id) FROM datacenter_storage_domain_map as a GROUP BY a.storage_domain_id, a.datacenter_id)
       and detach_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_configuration_history_storage_domains
+CREATE OR REPLACE VIEW v4_4_configuration_history_storage_domains
  AS
 SELECT
       history_id as history_id,
@@ -74,7 +74,7 @@ SELECT
       delete_date as delete_date
 FROM storage_domain_configuration;
 
-CREATE OR REPLACE VIEW v4_1_latest_configuration_storage_domains
+CREATE OR REPLACE VIEW v4_4_latest_configuration_storage_domains
  AS
 SELECT
       history_id as history_id,
@@ -88,7 +88,7 @@ FROM storage_domain_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM storage_domain_configuration as a GROUP BY a.storage_domain_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_statistics_storage_domains_resources_usage_samples
+CREATE OR REPLACE VIEW v4_4_statistics_storage_domains_resources_usage_samples
  AS
 SELECT
       history_id as history_id,
@@ -102,7 +102,7 @@ SELECT
       storage_configuration_version as storage_configuration_version
 FROM storage_domain_samples_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_storage_domains_resources_usage_hourly
+CREATE OR REPLACE VIEW v4_4_statistics_storage_domains_resources_usage_hourly
  AS
 SELECT
       history_id as history_id,
@@ -116,7 +116,7 @@ SELECT
       storage_configuration_version as storage_configuration_version
 FROM storage_domain_hourly_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_storage_domains_resources_usage_daily
+CREATE OR REPLACE VIEW v4_4_statistics_storage_domains_resources_usage_daily
  AS
 SELECT
       history_id as history_id,
@@ -130,7 +130,7 @@ SELECT
       storage_configuration_version as storage_configuration_version
 FROM storage_domain_daily_history;
 
-CREATE OR REPLACE VIEW v4_1_configuration_history_clusters
+CREATE OR REPLACE VIEW v4_4_configuration_history_clusters
  AS
 SELECT
       history_id as history_id,
@@ -146,7 +146,7 @@ SELECT
       delete_date as delete_date
 FROM cluster_configuration;
 
-CREATE OR REPLACE VIEW v4_1_latest_configuration_clusters
+CREATE OR REPLACE VIEW v4_4_latest_configuration_clusters
  AS
 SELECT
       history_id as history_id,
@@ -163,7 +163,7 @@ FROM cluster_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM cluster_configuration as a GROUP BY a.cluster_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_configuration_history_hosts
+CREATE OR REPLACE VIEW v4_4_configuration_history_hosts
  AS
 SELECT
       history_id as history_id,
@@ -200,7 +200,7 @@ SELECT
       delete_date as delete_date
 FROM host_configuration;
 
-CREATE OR REPLACE VIEW v4_1_latest_configuration_hosts
+CREATE OR REPLACE VIEW v4_4_latest_configuration_hosts
  AS
 SELECT
       history_id as history_id,
@@ -238,7 +238,7 @@ FROM host_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM host_configuration as a GROUP BY a.host_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_statistics_hosts_resources_usage_samples
+CREATE OR REPLACE VIEW v4_4_statistics_hosts_resources_usage_samples
  AS
 SELECT
       history_id as history_id,
@@ -261,7 +261,7 @@ SELECT
       host_configuration_version as host_configuration_version
 FROM host_samples_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_hosts_resources_usage_hourly
+CREATE OR REPLACE VIEW v4_4_statistics_hosts_resources_usage_hourly
  AS
 SELECT
       history_id as history_id,
@@ -295,7 +295,7 @@ SELECT
       host_configuration_version as host_configuration_version
 FROM host_hourly_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_hosts_resources_usage_daily
+CREATE OR REPLACE VIEW v4_4_statistics_hosts_resources_usage_daily
  AS
 SELECT
       history_id as history_id,
@@ -329,7 +329,7 @@ SELECT
       host_configuration_version as host_configuration_version
 FROM host_daily_history;
 
-CREATE OR REPLACE VIEW v4_1_configuration_history_hosts_interfaces
+CREATE OR REPLACE VIEW v4_4_configuration_history_hosts_interfaces
  AS
 SELECT
       history_id as history_id,
@@ -351,7 +351,7 @@ SELECT
       delete_date as delete_date
 FROM host_interface_configuration;
 
-CREATE OR REPLACE VIEW v4_1_latest_configuration_hosts_interfaces
+CREATE OR REPLACE VIEW v4_4_latest_configuration_hosts_interfaces
  AS
 SELECT
       history_id as history_id,
@@ -374,7 +374,7 @@ FROM host_interface_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM host_interface_configuration as a GROUP BY a.host_interface_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_statistics_hosts_interfaces_resources_usage_samples
+CREATE OR REPLACE VIEW v4_4_statistics_hosts_interfaces_resources_usage_samples
  AS
 SELECT
       history_id as history_id,
@@ -387,7 +387,7 @@ SELECT
       host_interface_configuration_version as host_interface_configuration_version
 FROM host_interface_samples_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_hosts_interfaces_resources_usage_hourly
+CREATE OR REPLACE VIEW v4_4_statistics_hosts_interfaces_resources_usage_hourly
  AS
 SELECT
       history_id as history_id,
@@ -402,7 +402,7 @@ SELECT
       host_interface_configuration_version as host_interface_configuration_version
 FROM host_interface_hourly_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_hosts_interfaces_resources_usage_daily
+CREATE OR REPLACE VIEW v4_4_statistics_hosts_interfaces_resources_usage_daily
  AS
 
 SELECT
@@ -418,7 +418,7 @@ SELECT
       host_interface_configuration_version as host_interface_configuration_version
 FROM host_interface_daily_history;
 
-CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_hosts_resources_usage_samples
+CREATE OR REPLACE VIEW v4_4_fully_joined_statistics_hosts_resources_usage_samples
  AS
 SELECT
     conf.host_id as host_id,
@@ -480,17 +480,17 @@ SELECT
     nic_stats.transmit_rate_percent as transmit_rate_percent,
     nic_stats.received_total_byte as received_total_byte,
     nic_stats.transmitted_total_byte as transmitted_total_byte
-FROM v4_1_configuration_history_hosts AS conf
-    LEFT OUTER JOIN v4_1_statistics_hosts_resources_usage_samples AS stats
+FROM v4_4_configuration_history_hosts AS conf
+    LEFT OUTER JOIN v4_4_statistics_hosts_resources_usage_samples AS stats
         ON (conf.history_id = stats.host_configuration_version)
-    LEFT OUTER JOIN v4_1_configuration_history_hosts_interfaces nic_conf
+    LEFT OUTER JOIN v4_4_configuration_history_hosts_interfaces nic_conf
         ON (conf.history_id = nic_conf.host_configuration_version)
-    LEFT OUTER JOIN v4_1_statistics_hosts_interfaces_resources_usage_samples nic_stats
+    LEFT OUTER JOIN v4_4_statistics_hosts_interfaces_resources_usage_samples nic_stats
         ON (nic_conf.history_id = nic_stats.host_interface_configuration_version AND
             stats.history_datetime = nic_stats.history_datetime);
 
 
-CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_hosts_resources_usage_hourly
+CREATE OR REPLACE VIEW v4_4_fully_joined_statistics_hosts_resources_usage_hourly
  AS
 SELECT
     conf.host_id as host_id,
@@ -565,17 +565,17 @@ SELECT
     nic_stats.max_transmit_rate_percent as max_transmit_rate_percent,
     nic_stats.received_total_byte as received_total_byte,
     nic_stats.transmitted_total_byte as transmitted_total_byte
-FROM v4_1_configuration_history_hosts AS conf
-    LEFT OUTER JOIN v4_1_statistics_hosts_resources_usage_hourly AS stats
+FROM v4_4_configuration_history_hosts AS conf
+    LEFT OUTER JOIN v4_4_statistics_hosts_resources_usage_hourly AS stats
         ON (conf.history_id = stats.host_configuration_version)
-    LEFT OUTER JOIN v4_1_configuration_history_hosts_interfaces nic_conf
+    LEFT OUTER JOIN v4_4_configuration_history_hosts_interfaces nic_conf
         ON (conf.history_id = nic_conf.host_configuration_version)
-    LEFT OUTER JOIN v4_1_statistics_hosts_interfaces_resources_usage_hourly nic_stats
+    LEFT OUTER JOIN v4_4_statistics_hosts_interfaces_resources_usage_hourly nic_stats
         ON (nic_conf.history_id = nic_stats.host_interface_configuration_version AND
             stats.history_datetime = nic_stats.history_datetime);
 
 
-CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_hosts_resources_usage_daily
+CREATE OR REPLACE VIEW v4_4_fully_joined_statistics_hosts_resources_usage_daily
  AS
 SELECT
     conf.host_id as host_id,
@@ -650,17 +650,17 @@ SELECT
     nic_stats.max_transmit_rate_percent as max_transmit_rate_percent,
     nic_stats.received_total_byte as received_total_byte,
     nic_stats.transmitted_total_byte as transmitted_total_byte
-FROM v4_1_configuration_history_hosts AS conf
-    LEFT OUTER JOIN v4_1_statistics_hosts_resources_usage_daily AS stats
+FROM v4_4_configuration_history_hosts AS conf
+    LEFT OUTER JOIN v4_4_statistics_hosts_resources_usage_daily AS stats
         ON (conf.history_id = stats.host_configuration_version)
-    LEFT OUTER JOIN v4_1_configuration_history_hosts_interfaces nic_conf
+    LEFT OUTER JOIN v4_4_configuration_history_hosts_interfaces nic_conf
         ON (conf.history_id = nic_conf.host_configuration_version)
-    LEFT OUTER JOIN v4_1_statistics_hosts_interfaces_resources_usage_daily nic_stats
+    LEFT OUTER JOIN v4_4_statistics_hosts_interfaces_resources_usage_daily nic_stats
         ON (nic_conf.history_id = nic_stats.host_interface_configuration_version AND
             stats.history_datetime = nic_stats.history_datetime);
 
 
-CREATE OR REPLACE VIEW v4_1_configuration_history_vms
+CREATE OR REPLACE VIEW v4_4_configuration_history_vms
  AS
 SELECT
       history_id as history_id,
@@ -692,7 +692,7 @@ SELECT
       delete_date as delete_date
 FROM vm_configuration;
 
-CREATE OR REPLACE VIEW v4_1_latest_configuration_vms
+CREATE OR REPLACE VIEW v4_4_latest_configuration_vms
  AS
 SELECT
       history_id as history_id,
@@ -725,7 +725,7 @@ FROM vm_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM vm_configuration as a GROUP BY a.vm_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_resources_usage_samples
+CREATE OR REPLACE VIEW v4_4_statistics_vms_resources_usage_samples
  AS
 SELECT
     a.history_id as history_id,
@@ -752,7 +752,7 @@ FROM     vm_samples_history as a
         LEFT OUTER JOIN vm_disks_usage_samples_history as b
             ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id);
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_resources_usage_hourly
+CREATE OR REPLACE VIEW v4_4_statistics_vms_resources_usage_hourly
  AS
 SELECT
     a.history_id as history_id,
@@ -783,7 +783,7 @@ FROM     vm_hourly_history as a
         LEFT OUTER JOIN vm_disks_usage_hourly_history as b
             ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id);
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_resources_usage_daily
+CREATE OR REPLACE VIEW v4_4_statistics_vms_resources_usage_daily
  AS
 SELECT
     a.history_id as history_id,
@@ -814,7 +814,7 @@ FROM     vm_daily_history as a
         LEFT OUTER JOIN vm_disks_usage_daily_history as b
             ON (a.history_datetime = b.history_datetime AND a.vm_id = b.vm_id);
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_users_usage_hourly
+CREATE OR REPLACE VIEW v4_4_statistics_vms_users_usage_hourly
  AS
 SELECT history_id,
        history_datetime,
@@ -837,7 +837,7 @@ SELECT history_id,
        current_host_configuration_version
 FROM statistics_vms_users_usage_hourly;
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_users_usage_daily
+CREATE OR REPLACE VIEW v4_4_statistics_vms_users_usage_daily
  AS
 SELECT history_id,
        history_datetime,
@@ -860,7 +860,7 @@ SELECT history_id,
        current_host_configuration_version
 FROM statistics_vms_users_usage_daily;
 
-CREATE OR REPLACE VIEW v4_1_configuration_history_vms_interfaces
+CREATE OR REPLACE VIEW v4_4_configuration_history_vms_interfaces
  AS
 SELECT
       history_id as history_id,
@@ -876,7 +876,7 @@ SELECT
       delete_date as delete_date
 FROM vm_interface_configuration;
 
-CREATE OR REPLACE VIEW v4_1_latest_configuration_vms_interfaces
+CREATE OR REPLACE VIEW v4_4_latest_configuration_vms_interfaces
  AS
 SELECT
       history_id as history_id,
@@ -893,7 +893,7 @@ FROM vm_interface_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM vm_interface_configuration as a GROUP BY a.vm_interface_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_interfaces_resources_usage_samples
+CREATE OR REPLACE VIEW v4_4_statistics_vms_interfaces_resources_usage_samples
  AS
 
 SELECT
@@ -907,7 +907,7 @@ SELECT
       vm_interface_configuration_version as vm_interface_configuration_version
 FROM vm_interface_samples_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_interfaces_resources_usage_hourly
+CREATE OR REPLACE VIEW v4_4_statistics_vms_interfaces_resources_usage_hourly
  AS
 
 SELECT
@@ -923,7 +923,7 @@ SELECT
       vm_interface_configuration_version as vm_interface_configuration_version
 FROM vm_interface_hourly_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_interfaces_resources_usage_daily
+CREATE OR REPLACE VIEW v4_4_statistics_vms_interfaces_resources_usage_daily
  AS
 
 SELECT
@@ -939,7 +939,7 @@ SELECT
       vm_interface_configuration_version as vm_interface_configuration_version
 FROM vm_interface_daily_history;
 
-CREATE OR REPLACE VIEW v4_1_configuration_history_vms_disks
+CREATE OR REPLACE VIEW v4_4_configuration_history_vms_disks
  AS
 SELECT
     history_id as history_id,
@@ -949,7 +949,6 @@ SELECT
           ELSE 'disk ' || cast(vm_internal_drive_mapping as varchar)
     END as vm_disk_name,
     vm_disk_description as vm_disk_description,
-    cast(NULL as uuid) as image_id,
     storage_domain_id as storage_domain_id,
     vm_disk_size_mb as vm_disk_size_mb,
     vm_disk_type as vm_disk_type,
@@ -960,7 +959,7 @@ SELECT
     delete_date as delete_date
 FROM vm_disk_configuration;
 
-CREATE OR REPLACE VIEW v4_1_latest_configuration_vms_disks
+CREATE OR REPLACE VIEW v4_4_latest_configuration_vms_disks
  AS
 SELECT
     history_id as history_id,
@@ -970,7 +969,6 @@ SELECT
           ELSE 'disk ' || cast(vm_internal_drive_mapping as varchar)
     END as vm_disk_name,
     vm_disk_description as vm_disk_description,
-    cast(NULL as uuid) as image_id,
     storage_domain_id as storage_domain_id,
     vm_disk_size_mb as vm_disk_size_mb,
     vm_disk_type as vm_disk_type,
@@ -982,7 +980,7 @@ FROM vm_disk_configuration
 WHERE history_id in (SELECT max(a.history_id) FROM vm_disk_configuration as a GROUP BY a.vm_disk_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_disks_resources_usage_samples
+CREATE OR REPLACE VIEW v4_4_statistics_vms_disks_resources_usage_samples
  AS
 SELECT
     history_id as history_id,
@@ -993,14 +991,16 @@ SELECT
     cast(seconds_in_status as numeric(7,2)) / 60 as minutes_in_status,
     vm_disk_actual_size_mb as vm_disk_actual_size_mb,
     read_rate_bytes_per_second as read_rate_bytes_per_second,
+    read_ops_per_second as read_ops_per_second,
     read_latency_seconds as read_latency_seconds,
     write_rate_bytes_per_second as write_rate_bytes_per_second,
+    write_ops_per_second as write_ops_per_second,
     write_latency_seconds as write_latency_seconds,
     flush_latency_seconds as flush_latency_seconds,
     vm_disk_configuration_version as vm_disk_configuration_version
 FROM vm_disk_samples_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_disks_resources_usage_hourly
+CREATE OR REPLACE VIEW v4_4_statistics_vms_disks_resources_usage_hourly
  AS
 SELECT
     history_id as history_id,
@@ -1012,10 +1012,14 @@ SELECT
     vm_disk_actual_size_mb as vm_disk_actual_size_mb,
     read_rate_bytes_per_second as read_rate_bytes_per_second,
     max_read_rate_bytes_per_second as max_read_rate_bytes_per_second,
+    read_ops_per_second as read_ops_per_second,
+    max_read_ops_per_second as max_read_ops_per_second,
     read_latency_seconds as read_latency_seconds,
     max_read_latency_seconds as max_read_latency_seconds,
     write_rate_bytes_per_second as write_rate_bytes_per_second,
     max_write_rate_bytes_per_second as max_write_rate_bytes_per_second,
+    write_ops_per_second as write_ops_per_second,
+    max_write_ops_per_second as max_write_ops_per_second,
     write_latency_seconds as write_latency_seconds,
     max_write_latency_seconds as max_write_latency_seconds,
     flush_latency_seconds as flush_latency_seconds,
@@ -1023,7 +1027,7 @@ SELECT
     vm_disk_configuration_version as vm_disk_configuration_version
 FROM vm_disk_hourly_history;
 
-CREATE OR REPLACE VIEW v4_1_statistics_vms_disks_resources_usage_daily
+CREATE OR REPLACE VIEW v4_4_statistics_vms_disks_resources_usage_daily
  AS
 SELECT
     history_id as history_id,
@@ -1035,10 +1039,14 @@ SELECT
     vm_disk_actual_size_mb as vm_disk_actual_size_mb,
     read_rate_bytes_per_second as read_rate_bytes_per_second,
     max_read_rate_bytes_per_second as max_read_rate_bytes_per_second,
+    read_ops_per_second as read_ops_per_second,
+    max_read_ops_per_second as max_read_ops_per_second,
     read_latency_seconds as read_latency_seconds,
     max_read_latency_seconds as max_read_latency_seconds,
     write_rate_bytes_per_second as write_rate_bytes_per_second,
     max_write_rate_bytes_per_second as max_write_rate_bytes_per_second,
+    write_ops_per_second as write_ops_per_second,
+    max_write_ops_per_second as max_write_ops_per_second,
     write_latency_seconds as write_latency_seconds,
     max_write_latency_seconds as max_write_latency_seconds,
     flush_latency_seconds as flush_latency_seconds,
@@ -1046,7 +1054,7 @@ SELECT
     vm_disk_configuration_version as vm_disk_configuration_version
 FROM vm_disk_daily_history;
 
-CREATE OR REPLACE VIEW v4_1_configuration_history_vms_devices
+CREATE OR REPLACE VIEW v4_4_configuration_history_vms_devices
  AS
 SELECT
     history_id as history_id,
@@ -1064,7 +1072,7 @@ SELECT
     delete_date
 FROM vm_device_history;
 
-CREATE OR REPLACE VIEW v4_1_latest_configuration_vms_devices
+CREATE OR REPLACE VIEW v4_4_latest_configuration_vms_devices
  AS
 SELECT
     history_id as history_id,
@@ -1083,7 +1091,7 @@ FROM vm_device_history
 WHERE history_id in (SELECT max(a.history_id) FROM vm_device_history as a GROUP BY a.vm_id, a.device_id)
       and delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_vms_resources_usage_samples
+CREATE OR REPLACE VIEW v4_4_fully_joined_statistics_vms_resources_usage_samples
  AS
  SELECT
     conf.vm_id as vm_id,
@@ -1154,7 +1162,6 @@ CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_vms_resources_usage_samples
     disk_conf.vm_disk_id as vm_disk_id,
     disk_conf.vm_disk_name as vm_disk_name,
     disk_conf.vm_disk_description as vm_disk_description,
-    cast(NULL as uuid) as image_id,
     disk_conf.storage_domain_id as storage_domain_id,
     disk_conf.vm_disk_size_mb as vm_disk_size_mb,
     disk_conf.vm_disk_type as vm_disk_type,
@@ -1172,24 +1179,24 @@ CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_vms_resources_usage_samples
     disk_stats.write_rate_bytes_per_second as write_rate_bytes_per_second,
     disk_stats.write_latency_seconds as write_latency_seconds,
     disk_stats.flush_latency_seconds as flush_latency_seconds
-FROM v4_1_configuration_history_vms AS conf
-    LEFT OUTER JOIN v4_1_statistics_vms_resources_usage_samples AS stats
+FROM v4_4_configuration_history_vms AS conf
+    LEFT OUTER JOIN v4_4_statistics_vms_resources_usage_samples AS stats
         ON (conf.history_id = stats.vm_configuration_version)
-    LEFT OUTER JOIN  v4_1_configuration_history_vms_devices device_conf
+    LEFT OUTER JOIN  v4_4_configuration_history_vms_devices device_conf
         ON (conf.history_id = device_conf.vm_configuration_version)
-    LEFT OUTER JOIN v4_1_configuration_history_vms_disks disk_conf
+    LEFT OUTER JOIN v4_4_configuration_history_vms_disks disk_conf
         ON (device_conf.device_configuration_version = disk_conf.history_id)
-    LEFT OUTER JOIN v4_1_configuration_history_vms_interfaces AS nic_conf
+    LEFT OUTER JOIN v4_4_configuration_history_vms_interfaces AS nic_conf
         ON (device_conf.device_configuration_version = nic_conf.history_id  AND
             conf.history_id = nic_conf.vm_configuration_version)
-    LEFT OUTER JOIN v4_1_statistics_vms_interfaces_resources_usage_samples AS nic_stats
+    LEFT OUTER JOIN v4_4_statistics_vms_interfaces_resources_usage_samples AS nic_stats
         ON (nic_conf.history_id = nic_stats.vm_interface_configuration_version AND
             stats.history_datetime = nic_stats.history_datetime)
-    LEFT OUTER JOIN v4_1_statistics_vms_disks_resources_usage_samples disk_stats
+    LEFT OUTER JOIN v4_4_statistics_vms_disks_resources_usage_samples disk_stats
         ON (disk_conf.history_id = disk_stats.vm_disk_configuration_version AND
             stats.history_datetime = disk_stats.history_datetime);
 
-CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_vms_resources_usage_hourly
+CREATE OR REPLACE VIEW v4_4_fully_joined_statistics_vms_resources_usage_hourly
  AS
  SELECT
     conf.vm_id as vm_id,
@@ -1266,7 +1273,6 @@ CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_vms_resources_usage_hourly
     disk_conf.vm_disk_id as vm_disk_id,
     disk_conf.vm_disk_name as vm_disk_name,
     disk_conf.vm_disk_description as vm_disk_description,
-    cast(NULL as uuid) as image_id,
     disk_conf.storage_domain_id as storage_domain_id,
     disk_conf.vm_disk_size_mb as vm_disk_size_mb,
     disk_conf.vm_disk_type as vm_disk_type,
@@ -1289,25 +1295,25 @@ CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_vms_resources_usage_hourly
     disk_stats.max_write_latency_seconds as max_write_latency_seconds,
     disk_stats.flush_latency_seconds as flush_latency_seconds,
     disk_stats.max_flush_latency_seconds as max_flush_latency_seconds
-FROM v4_1_configuration_history_vms AS conf
-    LEFT OUTER JOIN v4_1_statistics_vms_resources_usage_hourly AS stats
+FROM v4_4_configuration_history_vms AS conf
+    LEFT OUTER JOIN v4_4_statistics_vms_resources_usage_hourly AS stats
         ON (conf.history_id = stats.vm_configuration_version)
-    LEFT OUTER JOIN  v4_1_configuration_history_vms_devices device_conf
+    LEFT OUTER JOIN  v4_4_configuration_history_vms_devices device_conf
         ON (conf.history_id = device_conf.vm_configuration_version)
-    LEFT OUTER JOIN v4_1_configuration_history_vms_disks disk_conf
+    LEFT OUTER JOIN v4_4_configuration_history_vms_disks disk_conf
         ON (device_conf.device_configuration_version = disk_conf.history_id)
-    LEFT OUTER JOIN v4_1_configuration_history_vms_interfaces AS nic_conf
+    LEFT OUTER JOIN v4_4_configuration_history_vms_interfaces AS nic_conf
         ON (device_conf.device_configuration_version = nic_conf.history_id  AND
             conf.history_id = nic_conf.vm_configuration_version)
-    LEFT OUTER JOIN v4_1_statistics_vms_interfaces_resources_usage_hourly AS nic_stats
+    LEFT OUTER JOIN v4_4_statistics_vms_interfaces_resources_usage_hourly AS nic_stats
         ON (nic_conf.history_id = nic_stats.vm_interface_configuration_version AND
             stats.history_datetime = nic_stats.history_datetime)
-    LEFT OUTER JOIN v4_1_statistics_vms_disks_resources_usage_hourly disk_stats
+    LEFT OUTER JOIN v4_4_statistics_vms_disks_resources_usage_hourly disk_stats
         ON (disk_conf.history_id = disk_stats.vm_disk_configuration_version AND
             stats.history_datetime = disk_stats.history_datetime);
 
 
-CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_vms_resources_usage_daily
+CREATE OR REPLACE VIEW v4_4_fully_joined_statistics_vms_resources_usage_daily
  AS
  SELECT
     conf.vm_id as vm_id,
@@ -1384,7 +1390,6 @@ CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_vms_resources_usage_daily
     disk_conf.vm_disk_id as vm_disk_id,
     disk_conf.vm_disk_name as vm_disk_name,
     disk_conf.vm_disk_description as vm_disk_description,
-    cast(NULL as uuid) as image_id,
     disk_conf.storage_domain_id as storage_domain_id,
     disk_conf.vm_disk_size_mb as vm_disk_size_mb,
     disk_conf.vm_disk_type as vm_disk_type,
@@ -1407,24 +1412,24 @@ CREATE OR REPLACE VIEW v4_1_fully_joined_statistics_vms_resources_usage_daily
     disk_stats.max_write_latency_seconds as max_write_latency_seconds,
     disk_stats.flush_latency_seconds as flush_latency_seconds,
     disk_stats.max_flush_latency_seconds as max_flush_latency_seconds
-FROM v4_1_configuration_history_vms AS conf
-    LEFT OUTER JOIN v4_1_statistics_vms_resources_usage_daily AS stats
+FROM v4_4_configuration_history_vms AS conf
+    LEFT OUTER JOIN v4_4_statistics_vms_resources_usage_daily AS stats
         ON (conf.history_id = stats.vm_configuration_version)
-    LEFT OUTER JOIN  v4_1_configuration_history_vms_devices device_conf
+    LEFT OUTER JOIN  v4_4_configuration_history_vms_devices device_conf
         ON (conf.history_id = device_conf.vm_configuration_version)
-    LEFT OUTER JOIN v4_1_configuration_history_vms_disks disk_conf
+    LEFT OUTER JOIN v4_4_configuration_history_vms_disks disk_conf
         ON (device_conf.device_configuration_version = disk_conf.history_id)
-    LEFT OUTER JOIN v4_1_configuration_history_vms_interfaces AS nic_conf
+    LEFT OUTER JOIN v4_4_configuration_history_vms_interfaces AS nic_conf
         ON (device_conf.device_configuration_version = nic_conf.history_id  AND
             conf.history_id = nic_conf.vm_configuration_version)
-    LEFT OUTER JOIN v4_1_statistics_vms_interfaces_resources_usage_daily AS nic_stats
+    LEFT OUTER JOIN v4_4_statistics_vms_interfaces_resources_usage_daily AS nic_stats
         ON (nic_conf.history_id = nic_stats.vm_interface_configuration_version AND
             stats.history_datetime = nic_stats.history_datetime)
-    LEFT OUTER JOIN v4_1_statistics_vms_disks_resources_usage_daily disk_stats
+    LEFT OUTER JOIN v4_4_statistics_vms_disks_resources_usage_daily disk_stats
         ON (disk_conf.history_id = disk_stats.vm_disk_configuration_version AND
             stats.history_datetime = disk_stats.history_datetime);
 
-CREATE OR REPLACE VIEW v4_1_users_details_history
+CREATE OR REPLACE VIEW v4_4_users_details_history
  AS
 SELECT
       user_id,
@@ -1442,7 +1447,7 @@ SELECT
       delete_date
 FROM users_details_history;
 
-CREATE OR REPLACE VIEW v4_1_latest_users_details
+CREATE OR REPLACE VIEW v4_4_latest_users_details
  AS
 SELECT
       user_id,
@@ -1461,7 +1466,7 @@ SELECT
 FROM users_details_history
 WHERE delete_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_tags_relations_history
+CREATE OR REPLACE VIEW v4_4_tags_relations_history
  AS
 SELECT    history_id as history_id,
         entity_id as entity_id,
@@ -1472,7 +1477,7 @@ SELECT    history_id as history_id,
 FROM         tag_relations_history
 WHERE       entity_type in(3,2,5,18,15);
 
-CREATE OR REPLACE VIEW v4_1_latest_tags_relations
+CREATE OR REPLACE VIEW v4_4_latest_tags_relations
  AS
 SELECT    history_id as history_id,
         entity_id as entity_id,
@@ -1485,7 +1490,7 @@ WHERE       entity_type in(3,2,5,18,15)
        and history_id in (SELECT max(a.history_id) FROM tag_relations_history as a GROUP BY a.entity_id, a.parent_id)
        and detach_date IS NULL;
 
-CREATE OR REPLACE VIEW v4_1_tags_details_history
+CREATE OR REPLACE VIEW v4_4_tags_details_history
  AS
 SELECT  history_id as history_id,
         tag_id as tag_id,
@@ -1498,7 +1503,7 @@ SELECT  history_id as history_id,
         delete_date as delete_date
 FROM         tag_details;
 
-CREATE OR REPLACE VIEW v4_1_latest_tags_details
+CREATE OR REPLACE VIEW v4_4_latest_tags_details
  AS
 SELECT  history_id as history_id,
         tag_id as tag_id,
